@@ -247,53 +247,6 @@ SEXP R_H5Dget_chunk_index_type(SEXP R_did, SEXP R_idx_type){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_bytes); */
-SEXP R_H5Dget_chunk_storage_size(SEXP R_dset_id, SEXP R_offset, SEXP R_chunk_bytes){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_chunk_bytes = PROTECT(duplicate(R_chunk_bytes));
-  vars_protected++;
-  hid_t dset_id = SEXP_to_longlong(R_dset_id, 0);
-  const hsize_t* offset;
-  if(XLENGTH(R_offset) == 0) {
-    offset = NULL;
-  }
-  else {
-    R_helper = PROTECT(RToH5(R_offset, h5_datatype[DT_hsize_t], XLENGTH(R_offset)));
-    offset= (const hsize_t*) VOIDPTR(R_helper);
-    vars_protected++;
-  }
-  hsize_t* chunk_bytes;
-  if(XLENGTH(R_chunk_bytes) == 0) {
-    chunk_bytes = NULL;
-  }
-  else {
-    R_helper = PROTECT(RToH5(R_chunk_bytes, h5_datatype[DT_hsize_t], XLENGTH(R_chunk_bytes)));
-    chunk_bytes= (hsize_t*) VOIDPTR(R_helper);
-    vars_protected++;
-  }
-  herr_t return_val = H5Dget_chunk_storage_size(dset_id, offset, chunk_bytes);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_chunk_bytes, h5_datatype[DT_hsize_t]);
-  R_chunk_bytes = PROTECT(H5ToR_single_step(chunk_bytes, h5_datatype[DT_hsize_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_chunk_bytes);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("chunk_bytes"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL hid_t H5Dget_create_plist(hid_t dset_id); */
 SEXP R_H5Dget_create_plist(SEXP R_dset_id){
   int vars_protected=0;
